
update_map <- function(smc) {
    if (is.na(match("map", names(smc)))) {
        stop("No 'map' object in given 'smc'.")
    }

    if (is.na(match("position", colnames(smc$map)))) {
        stop("Invalid 'map' in given 'smc', no 'position' field.")
    }

    if (is.na(match("snp.name", colnames(smc$map)))) {
        stop("Invalid 'map' in given 'smc', no 'snp.name' field.")
    }

    sel <- !smc$map$dbSNP == "---"
    annot <- smc$map[sel,c(2,1,3)]    

    mart <- useMart(biomart="snp", dataset="hsapiens_snp") ## GRCh37.p13
    
    results <- getBM(attributes=c("refsnp_id", "chr_name", "chrom_start"), filters="snp_filter", values=annot$dbSNP, mart=mart)
    rm("annot", "sel", "mart")

    results <- results[!duplicated(results$refsnp_id), ]
    nmap <- smc$map[smc$map$dbSNP %in% results$refsnp_id, ]
    nmap$position <- results$chrom_start
    nmap <- nmap[order(nmap$chromosome, nmap$position), ]

    return(list(genotype=smc$genotype, map=nmap))
}

