
# Cyto2Mad
# -----------------------------------------------------------------------------
# Update: 24/12/2013

Cyto2Mad <- function(cychp.files, output.name, output.type = "mad",
    cychp.attime = 4, quantile.bottom = 0.25, quantile.top = 0.75,
    fill.24 = TRUE, verbose = FALSE) {

    # SETUP
    OptionsAffy.Init("Cyto2Mad", verbose)
    OptionsAffy.Cores(cychp.attime)
    # /SETUP

    # SYSTEM
    CheckSystem(bits=FALSE)
    # /SYSTEM

    # FUN CHECKS
    if( cychp.files == "" ) {
        cychp.files = "./";
    }
    output.type <- value(output.type, c("mad", "penncnv"))
    if (is.na(output.type)) {
        stop("Argument 'output.type' must be 'mad' or 'penncnv'.")
    }
    if (is.na(output.name) | output.name == '') {
        stop("Argument 'output.name' must be filled.")
    }
    files.complete <- list.files(cychp.files, pattern=".cyhd.cychp.txt", 
        full.names=TRUE)
    if (length(files.complete) == 0) {
        stop("No 'cychp' files in folder '", cychp.files, "'.")
    }
    # /FUN CHECKS

    output.temp <- RandomName(prefix="tmp.cyto.mad.")

    # ARGS
    m <- paste0( "\n\n",
        " - Input:        ", cychp.files, "\n",
        " - Temp path:    ", output.temp, "\n",
        " - cychp x time: ", cychp.attime, "\n",
        " - Output.t:     ", output.type, "\n",
        " - Output.f:     ", output.name, "\n");
    ScreenAffy(m)
    # /ARGS

    # CLEAN
    unlink(output.name, recursive=TRUE, force=TRUE)
    unlink(output.temp, recursive=TRUE, force=TRUE)
    dir.create(output.name, showWarnings=FALSE)
    dir.create(output.temp, showWarnings=FALSE)
    # /CLEAN

    data <- plapply(X=files.complete, FUN=CytoProcess.Mad, 
        output.temp=output.temp, output.name=output.name,
        bt=quantile.bottom, tt=quantile.top, 
        save=(output.type == "mad"), fill.24=fill.24)

    ScreenAffy("Number of individuals: ", length(data))

    if (output.type == "mad") {
        common <- List.Intersect(data)
        rm("data")
        
        ds <- plapply(X=list.files(output.name, full.names=TRUE),
            FUN=CytoPostprocess.Mad, probes.common=common)
        
        rm("ds")
    } else {
        unlink(output.name, recursive=TRUE, force=TRUE)

        f <- Reduce(intersect, lapply(data, function(x) { return(x$Name) }))

        result <- data[[1]];
        result <- result[result$Name %in% f, ]
        result <- result[!duplicated(result$Name), ]

        cel.name <- gsub(".cyhd.cychp.txt", "", basename(files.complete[1]))
        names <- c("Name", "Chr", "Position", paste0(cel.name, ".Log R Ratio"),
            paste0(cel.name, ".GType"), paste0(cel.name, ".B Allele Freq"));

        ScreenAffy("Flatting files to penncnv.");
        for(nf in 2:length(data)) {
            ScreenAffy("Flatting file '", nf, "'.")
            nn <- data[[nf]]
            nn <- nn[nn$Name %in% f, ]
            nn <- nn[!duplicated(nn$Name), ]

            result <- cbind(result, nn$Log.R.Ratio, nn$GType, nn$B.Allele.Freq)

            cel.name <- gsub(".cyhd.cychp.txt", "",
            basename(files.complete[nf ]));
            names <- c(names, paste0(cel.name, ".GType"),
                paste0(cel.name, ".Log R Ratio" ),
                paste0(cel.name, ".B Allele Freq"));
        }

        colnames(result) <- names;

        ScreenAffy("Saving file '", output.name, ".penncnv'.");
        write.table(result, file=paste0(output.name, ".penncnv"),
            quote=FALSE, row.names=FALSE, sep="\t", na="NA");
    }

    unlink(output.temp, recursive=TRUE, force=TRUE)
    return(NA);
}
