
# CytoPreprocess
# -----------------------------------------------------------------------------
# Created: 24/12/2013

CytoProcess.Mad <- function(cychp.file, output.temp, output.name, 
    bt, tt, save, fill.24) {

    #, ii, cychp.complete, output.path, output.temp,
    #    bt, tt, save, fill.24, verbose) {

    name <- gsub(".cyhd.cychp.txt", "", basename(cychp.file))
    ScreenAffy("Calling individual '", name ,"'.")

    # Call the python parser's to clean the data
    CytoParser(cychp.file, output.temp)
    # /Call the python parser's to clean the data

    # Create files' names
    genotype.file <- file.path(output.temp,
        paste0(name, ".cyhd.cychp.genotype.f.txt"), fsep=.Platform$file.sep)
    copynumber.file <- file.path(output.temp,
        paste0(name, ".cyhd.cychp.cnds.f.txt"), fsep=.Platform$file.sep)
    allelepeaks.file <- file.path(output.temp,
        paste0(name, ".cyhd.cychp.apds.f.txt"), fsep=.Platform$file.sep )
    # Create files' names


    # Load data
    ScreenAffy("Loading calls ('", name ,"').")
    continue <- TRUE
    gnds <- tryCatch( {
            read.delim( genotype.file, header=TRUE, as.is=TRUE )
        }, warnning=function(w) {
            OptionsAffy.AddError(error.name = genotype.file, 
                "Invalid file provided in 'genotype.file' (",
                    genotype.file ,") some error from 'python'.")
            continue <- FALSE
        }, error=function(e) {
            OptionsAffy.AddError(error.name = genotype.file, 
                "Invalid file provided in 'genotype.file' (",
                    genotype.file ,") some error from 'python'.")
            continue <- FALSE
        }
    )
    if (!continue) {
        ScreenAffy("Failed calling (gnds) for individual '", name ,"'.")
        return(NA)
    }

    ScreenAffy("Loading allele peaks ('", name ,"').")
    apds <- tryCatch( {
            read.delim(allelepeaks.file, sep="\t", header=TRUE, as.is=TRUE)
        }, warnning=function(w) {
            OptionsAffy.AddError(error.name = allelepeaks.file, 
                "Invalid file provided in 'allelepeaks.file' (",
                    allelepeaks.file ,") some error from 'python'.")
        }, error=function(e) {
            OptionsAffy.AddError(error.name = allelepeaks.file, 
                "Invalid file provided in 'allelepeaks.file' (",
                    allelepeaks.file ,") some error from 'python'.")
        }
    )
    if (!continue) {
        ScreenAffy("Failed calling (apds) for individual '", name ,"'.")
        return(NA)
    }

    ScreenAffy("Loading copynumber ('", name ,"').")
    cnds <- tryCatch( {
            read.delim(copynumber.file, header=TRUE, as.is=TRUE)
        }, warnning=function(w) {
            OptionsAffy.AddError(error.name = copynumber.file, 
                "Invalid file provided in 'copynumber.file' (",
                    copynumber.file ,") some error from 'python'.")
            continue <- FALSE
        }, error=function(e) {
            OptionsAffy.AddError(error.name = copynumber.file, 
                "Invalid file provided in 'copynumber.file' (",
                    copynumber.file ,") some error from 'python'.")
        }
    )
    if (!continue) {
        ScreenAffy("Failed calling (cnds) for individual '", name ,"'.")
        return(NA)
    }
    # /Load data


    # Process
    rownames(gnds) <- gnds$ProbeSetName
    rownames(apds) <- apds$ProbeSetName
    rownames(cnds) <- cnds$ProbeSetName

    ScreenAffy("Quantile filtering for individual '", name ,"'.")

    n <- quantile(apds$AllelePeaks0, c(bt, tt), rm.na=TRUE)
    apds$AllelePeaks0[apds$AllelePeaks0 < n[1]] <- n[1]
    apds$AllelePeaks0[apds$AllelePeaks0 > n[2]] <- n[2]

    ap <- (apds$AllelePeaks0 - n[1] ) / (n[2] - n[1])
    ap <- 1 - ap;

    ScreenAffy("Creating data.frame for individual '", name ,"'.")

    name <- file.path(output.name, name, fsep=.Platform$file.sep)

    madfile <- data.frame(cnds[rownames(apds), "ProbeSetName"],
        cnds[rownames(apds), "Chromosome"],
        cnds[rownames(apds), "Position"],
        cnds[rownames(apds), "Log2Ratio"],
        gnds[rownames(apds), "Call"], ap)
    
    colnames(madfile) <- c("Name", "Chr", "Position", "Log.R.Ratio", "GType",
        "B.Allele.Freq")

    rm('ap', 'apds', 'gnds', 'cnds')

    if (fill.24) {
        ScreenAffy("Filling chromosome 24 with dummy data from ",
            "chromosome 23 ('", name ,"').")
        
        lny <- round(sum(madfile$Chr == "X") / 3)
        cn <- madfile[madfile$Chr == "X", ][1:lny, ]
        cn[ , "Chr"] <- "Y"
        cn[ , "Name"] <- unlist(sapply(as.character(cn$Name),
            function(x){ paste0("Y-", x) } ))
        madfile <- rbind(madfile, cn)
    }

    ScreenAffy("Converting 'NC' to 'NA' ('", name ,"').")
    madfile$GType[madfile$GType=="NC"] <- NA

    if (save) {
        ScreenAffy("Writing file for individual '", name ,"'.")
        write.table(madfile, file=name, quote=FALSE, row.names=FALSE,
            sep="\t", na="NA")

        probes <- as.character(madfile$Name)
        rm('madfile')

        return(probes)
    } else {
        return(madfile)
    }
    # /Process
}




# CytoPostprocess.Mad
# -----------------------------------------------------------------------------
# Created: 26/12/2013

CytoPostprocess.Mad <- function(file.name, probes.common) {

    ScreenAffy("Post-process for individual '", file.name ,"'.")

    madfile <- read.table(file.name, header=TRUE, sep="\t")
    rownames(madfile) <- madfile$Name
    madfile <- madfile[probes.common, ]

    write.table(madfile, file=file.name, quote=FALSE, row.names=FALSE,
        sep="\t", na="NA")

    return(NA)
}

